@@ -52,7 +52,6 @@ about_cb (BonoboUIComponent *uic,
     };
 
     gtk_show_about_dialog (NULL,
-	"name",		_("System Monitor"),
 	"version",	VERSION,
 	"copyright",	"\xC2\xA9 1999-2005 Free Software Foundation "
 			"and others",
@@ -95,10 +94,15 @@ start_procman (MultiloadApplet *ma)
 {
 	GError *error = NULL;
 	GnomeDesktopItem *ditem;
+	gchar *monitor;
 
 	g_return_if_fail (ma != NULL);
 
-	if ((ditem = gnome_desktop_item_new_from_basename ("gnome-system-monitor.desktop", 0, NULL))) {
+	monitor = panel_applet_gconf_get_string (ma->applet, "system_monitor", NULL);
+	if (monitor == NULL)
+	        monitor = g_strdup ("gnome-system-monitor.desktop");
+
+	if ((ditem = gnome_desktop_item_new_from_basename (monitor, 0, NULL))) {
 		gnome_desktop_item_set_launch_time (ditem, gtk_get_current_event_time ());
 		gnome_desktop_item_launch_on_screen (ditem, NULL,
 		                                     GNOME_DESKTOP_ITEM_LAUNCH_ONLY_ONE,
@@ -111,6 +115,7 @@ start_procman (MultiloadApplet *ma)
 				gtk_widget_get_screen (GTK_WIDGET (ma->applet)),
 				"gnome-system-monitor", &error);
 	}
+	g_free (monitor);
 
 	if (error) {
 		GtkWidget *dialog;
@@ -284,7 +289,7 @@ multiload_applet_tooltip_update(LoadGraph *g)
 		name = g_strdup(_("Processor"));
 	else if (!strncmp(g->name, "memload", strlen("memload")))
 		name = g_strdup(_("Memory"));
-	else if (!strncmp(g->name, "netload", strlen("netload")))
+	else if (!strncmp(g->name, "netload2", strlen("netload2")))
 		name = g_strdup(_("Network"));
 	else if (!strncmp(g->name, "swapload", strlen("swapload")))
 		name = g_strdup(_("Swap Space"));
@@ -321,6 +326,17 @@ multiload_applet_tooltip_update(LoadGraph *g)
 		tooltip_text = g_strdup_printf(_("The system load average is %0.02f"),
 					       g->loadavg1);
 
+	} else if (!strcmp(g->name, "netload2")) {
+		char *tx_in, *tx_out;
+		tx_in = netspeed_get(g->netspeed_in);
+		tx_out = netspeed_get(g->netspeed_out);
+		/* xgettext: same as in graphic tab of g-s-m */
+		tooltip_text = g_strdup_printf(_("%s:\n"
+						 "Receiving %s\n"
+						 "Sending %s"),
+					       name, tx_in, tx_out);
+		g_free(tx_in);
+		g_free(tx_out);
 	} else {
 		const char *msg;
 		guint i, total_used, percent;
@@ -342,7 +358,7 @@ multiload_applet_tooltip_update(LoadGraph *g)
 					       percent);
 	}
 
-	gtk_tooltips_set_tip(g->tooltips, g->disp, tooltip_text, tooltip_text);
+	gtk_widget_set_tooltip_text(g->disp, tooltip_text);
 		
 	g_free(tooltip_text);
 	g_free(name);
@@ -358,7 +374,7 @@ multiload_create_graphs(MultiloadApplet *ma)
 	       } graph_types[] = {
 			{ _("CPU Load"),     "cpuload",  5, GetLoad },
 			{ _("Memory Load"),  "memload",  5, GetMemory },
-			{ _("Net Load"),     "netload",  5, GetNet },
+			{ _("Net Load"),     "netload2",  4, GetNet },
 			{ _("Swap Load"),    "swapload", 2, GetSwap },
 			{ _("Load Average"), "loadavg",  2, GetLoadAvg },
 			{ _("Disk Load"),    "diskload", 3, GetDiskLoad }
@@ -377,7 +393,14 @@ multiload_create_graphs(MultiloadApplet *ma)
 		gboolean visible;
 		char *key;
 
-		key = g_strdup_printf ("view_%s", graph_types[i].name);
+		/* This is a special case to handle migration from an
+		 * older version of netload to a newer one in the
+		 * 2.25.1 release. */
+		if (g_strcmp0 ("netload2", graph_types[i].name) == 0) {
+		  key = g_strdup ("view_netload");
+		} else {
+		  key = g_strdup_printf ("view_%s", graph_types[i].name);
+		}
 		visible = panel_applet_gconf_get_bool (ma->applet, key, NULL);
 		g_free (key);
 
@@ -471,6 +494,8 @@ multiload_applet_new(PanelApplet *applet, const gchar *iid, gpointer data)
 	ma->prop_dialog = NULL;
         ma->last_clicked = 0;
 
+	g_set_application_name (_("System Monitor"));
+
 	gtk_window_set_default_icon_name ("utilities-system-monitor");
 	panel_applet_set_background_widget (applet, GTK_WIDGET(applet));
 	
